"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var react_1 = __importDefault(require("react"));
var react_2 = require("@testing-library/react");
var contexts_1 = require("../../contexts");
var Button_1 = require("./Button");
var button;
describe('when rendered without props', function () {
    beforeEach(function () {
        react_2.render(react_1.default.createElement(contexts_1.ContextProvider, null,
            react_1.default.createElement(Button_1.Button, null)));
        button = react_2.screen.getByRole('button');
    });
    test('should render a button with type "button"', function () {
        expect(button).toHaveAttribute('type', 'button');
    });
    test('should render a button with the button class name', function () {
        expect(button.classList).toContain('rdp-button');
    });
    test('should render a button with the reset class name', function () {
        expect(button.classList).toContain('rdp-button_reset');
    });
});
describe('when using a class name from props', function () {
    beforeEach(function () {
        react_2.render(react_1.default.createElement(contexts_1.ContextProvider, null,
            react_1.default.createElement(Button_1.Button, { className: "foo" })));
        button = react_2.screen.getByRole('button');
    });
    test('should add the class name', function () {
        expect(button.classList).toContain('foo');
    });
});
describe('when using custom class names from DayPicker props', function () {
    beforeEach(function () {
        react_2.render(react_1.default.createElement(contexts_1.ContextProvider, { classNames: { button: 'foo-from-props' } },
            react_1.default.createElement(Button_1.Button, null)));
        button = react_2.screen.getByRole('button');
    });
    test('should add the class name', function () {
        expect(button.classList).toContain('foo-from-props');
    });
});
describe('when using a inline style from props', function () {
    beforeEach(function () {
        react_2.render(react_1.default.createElement(contexts_1.ContextProvider, null,
            react_1.default.createElement(Button_1.Button, { style: { color: 'red' } })));
        button = react_2.screen.getByRole('button');
    });
    test('should apply the style', function () {
        expect(button.style.color).toBe('red');
    });
});
describe('when using a inline style from DayPicker props', function () {
    beforeEach(function () {
        react_2.render(react_1.default.createElement(contexts_1.ContextProvider, { styles: { button: { color: 'blue' } } },
            react_1.default.createElement(Button_1.Button, null)));
        button = react_2.screen.getByRole('button');
    });
    test('should apply the style', function () {
        expect(button.style.color).toBe('blue');
    });
});
//# sourceMappingURL=Button.test.js.map