"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.useDayFocus = void 0;
var react_1 = __importDefault(require("react"));
var date_fns_1 = require("date-fns");
var contexts_1 = require("../../../contexts");
/** Handle the focus for the day element. */
function useDayFocus(date, buttonRef) {
    var _a = contexts_1.useFocus(), focusedDay = _a[0], _b = _a[1], focusDayAfter = _b.focusDayAfter, focusDayBefore = _b.focusDayBefore, focusDayDown = _b.focusDayDown, focusDayUp = _b.focusDayUp, blur = _b.blur, focus = _b.focus;
    // Focus the HTML element if this is the focused day.
    react_1.default.useEffect(function () {
        var _a;
        if (!focusedDay)
            return;
        if (date_fns_1.isSameDay(focusedDay, date)) {
            (_a = buttonRef.current) === null || _a === void 0 ? void 0 : _a.focus();
        }
    }, [focusedDay]);
    var focusOnKeyDown = function (e) {
        switch (e.key) {
            case 'ArrowLeft':
                e.preventDefault();
                e.stopPropagation();
                focusDayBefore();
                break;
            case 'ArrowRight':
                e.preventDefault();
                e.stopPropagation();
                focusDayAfter();
                break;
            case 'ArrowDown':
                e.preventDefault();
                e.stopPropagation();
                focusDayDown();
                break;
            case 'ArrowUp':
                e.preventDefault();
                e.stopPropagation();
                focusDayUp();
                break;
        }
    };
    var isFocused = Boolean(focusedDay && !date_fns_1.isSameDay(focusedDay, date));
    return { focus: focus, blur: blur, focusOnKeyDown: focusOnKeyDown, isFocused: isFocused };
}
exports.useDayFocus = useDayFocus;
//# sourceMappingURL=useDayFocus.js.map